@@ -11,6 +11,7 @@
 #include <QAbstractEventDispatcher>
 #include <QDBusConnection>
 #include <QDBusServiceWatcher>
+#include <QGuiApplication>
 #include <QMutexLocker>
 #include <QTimer>
 
@@ -28,6 +29,7 @@
 namespace QPulseAudio
 {
 Context *Context::s_context = nullptr;
+QString Context::s_applicationId;
 
 const qint64 Context::NormalVolume = PA_VOLUME_NORM;
 const qint64 Context::MinimalVolume = 0;
@@ -586,7 +588,11 @@ void Context::connectToDaemon()
 
     pa_proplist *proplist = pa_proplist_new();
     pa_proplist_sets(proplist, PA_PROP_APPLICATION_NAME, i18nc("Name shown in debug pulseaudio tools", "Plasma PA").toUtf8().constData());
-    pa_proplist_sets(proplist, PA_PROP_APPLICATION_ID, "org.kde.plasma-pa");
+    if (!s_applicationId.isEmpty()) {
+        pa_proplist_sets(proplist, PA_PROP_APPLICATION_ID, s_applicationId.toUtf8().constData());
+    } else {
+        pa_proplist_sets(proplist, PA_PROP_APPLICATION_ID, QGuiApplication::desktopFileName().toUtf8().constData());
+    }
     pa_proplist_sets(proplist, PA_PROP_APPLICATION_ICON_NAME, "audio-card");
     m_context = pa_context_new_with_proplist(api, nullptr, proplist);
     pa_proplist_free(proplist);
@@ -615,4 +621,9 @@ void Context::reset()
     m_server->reset();
 }
 
+void Context::setApplicationId(const QString &applicationId)
+{
+    s_applicationId = applicationId;
+}
+
 } // QPulseAudio
