@@ -1,21 +1,7 @@
 /*
-    Copyright 2014-2015 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2014-2015 Harald Sitter <sitter@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef DEVICE_H
@@ -25,13 +11,12 @@
 
 #include <pulse/volume.h>
 
-#include "volumeobject.h"
 #include "port.h"
 #include "pulseobject.h"
+#include "volumeobject.h"
 
 namespace QPulseAudio
 {
-
 class Device : public VolumeObject
 {
     Q_OBJECT
@@ -50,13 +35,15 @@ public:
         RunningState,
         IdleState,
         SuspendedState,
-        UnknownState
+        UnknownState,
     };
     Q_ENUMS(State);
 
-    ~Device() override {}
+    ~Device() override
+    {
+    }
 
-    template <typename PAInfo>
+    template<typename PAInfo>
     void updateDevice(const PAInfo *info)
     {
         updateVolumeObject(info);
@@ -78,25 +65,41 @@ public:
             }
         }
 
-        m_cardIndex = info->card;
-        Q_EMIT cardIndexChanged();
+        if (m_cardIndex != info->card) {
+            m_cardIndex = info->card;
+            Q_EMIT cardIndexChanged();
+        }
 
-        // TODO: this rebuilds the entire port list on every update. would be
-        // nicer if it actually removed what needs removing updates what needs
-        // updating and adds what needs adding. Alas, this is a tad more
-        // involved.
-        qDeleteAll(m_ports);
-        m_ports.clear();
+        const quint32 oldActivePortIndex = m_activePortIndex;
+        bool portsHaveChanged = false;
+        int i = 0;
         for (auto **ports = info->ports; ports && *ports != nullptr; ++ports) {
-            Port *port = new Port(this);
-            port->setInfo(*ports);
-            m_ports.append(port);
+            if (i < m_ports.count()) {
+                Port *port = static_cast<Port *>(m_ports.at(i));
+                portsHaveChanged |= port->setInfo(*ports);
+            } else {
+                Port *port = new Port(this);
+                port->setInfo(*ports);
+                m_ports.append(port);
+                portsHaveChanged = true;
+            }
             if (info->active_port == *ports) {
-                m_activePortIndex = m_ports.length() - 1;
+                m_activePortIndex = i;
             }
+            ++i;
+        }
+
+        while (m_ports.count() > i) {
+            delete m_ports.takeLast();
+            portsHaveChanged = true;
+        }
+
+        if (portsHaveChanged) {
+            Q_EMIT portsChanged();
+        }
+        if (portsHaveChanged || m_activePortIndex != oldActivePortIndex) {
+            Q_EMIT activePortIndexChanged();
         }
-        Q_EMIT portsChanged();
-        Q_EMIT activePortIndexChanged();
 
         State infoState = stateFromPaState(info->state);
         if (infoState != m_state) {
