@@ -14,8 +14,6 @@ namespace QPulseAudio
 {
 Server::Server(Context *context)
     : QObject(context)
-    , m_defaultSink(nullptr)
-    , m_defaultSource(nullptr)
 {
     Q_ASSERT(context);
 
@@ -67,6 +65,8 @@ void Server::update(const pa_server_info *info)
     m_isPipeWire = QString::fromUtf8(info->server_name).contains("PipeWire");
 
     updateDefaultDevices();
+
+    Q_EMIT updated();
 }
 
 template<typename Type, typename Map>
