@@ -8,7 +8,6 @@
 #define SINK_H
 
 #include "device.h"
-#include <canberra.h>
 #include <pulse/channelmap.h>
 
 namespace QPulseAudio
@@ -32,13 +31,13 @@ public:
 
     void switchStreams() override;
 
-    quint32 sourceIndex() const override;
+    quint32 monitorIndex() const;
 
-public Q_SLOTS:
-    void testChannel(const QString &name);
+Q_SIGNALS:
+    void monitorIndexChanged();
 
 private:
-    quint32 m_sourceIndex = -1;
+    quint32 m_monitorIndex = -1;
 };
 
 } // QPulseAudio
